# How-to Guides

## Collection

* [Build Playlists From Tags](collection_playlists.md)
* [Combine Playlists With Boolean Algebra](combiner_playlists.md)
* [Copy Tracks From Playlists](copy_playlists.md)
* [Shuffle Tracks in Playlists](shuffle_playlists.md)

## Spotify

* [Setup Reddit & Spotify API Access](reddit_spotify_api_access.md)
* [Create Spotify Playlists From Other Users' Uploads](spotify_playlist_from_upload.md)
* [Create Spotify Playlists From Reddit Posts](spotify_playlist_from_reddit.md)

## Sync

* [Setup Object Storage For Syncing Files](setup_object_storage.md)
* [Sync Files with the Beatcloud](sync_beatcloud.md)
* [Sync Tracks From Spotify Playlists](sync_spotify.md)

## Utils

* [Check the Beatcloud for Tracks in Spotify Playlists or Local Directories](check_beatcloud.md)
* [Extract Audio Files From URLs](extract_from_url.md)
* [Process Recorded Files Using Spotify Playlists](process_recordings.md)
* [Standardize Audio Files](standardize_audio.md)
